using System;
using System.Collections.Generic;
using System.Text;
using System.IO; // StreamWriter


namespace CheckInclude
{
    class Log
    {
        //-----------------------------------------------------------
        // Attributes
        //-----------------------------------------------------------

        // named bits for output devices
        private const int BIT_STDOUT = 1;
        private const int BIT_LOG_FILE = 2;    // detailed logfile
        private const int BIT_RESULT_FILE = 4; // only important results

        // names for adressing several output devices
        public const int ALL = BIT_STDOUT + BIT_LOG_FILE + BIT_RESULT_FILE;
        public const int STDOUT = BIT_STDOUT;
        public const int LOG = BIT_LOG_FILE;
        public const int RESULT = BIT_RESULT_FILE;
        public const int LOG_RESULT = BIT_LOG_FILE + BIT_RESULT_FILE;
        public const int STDOUT_LOG = BIT_STDOUT + BIT_LOG_FILE;
        public const int STDOUT_RESULT = BIT_STDOUT + BIT_RESULT_FILE;
        public const int STDOUT_LOG_RESULT = BIT_STDOUT + BIT_LOG_FILE + BIT_RESULT_FILE;

        public string m_nameLogFileFullPath;
        public string m_nameResultFileFullPath;


        //-----------------------------------------------------------
        // Public methods
        //-----------------------------------------------------------

        // Constructor
        public Log()
        {
            // Create all needed logfiles
            CreateLogFiles();
        }

        //-----------------------------------------------------------

        public void WriteTo(int in_outMode, string in_text)
        {
            if ((in_outMode & BIT_STDOUT) != 0)
            {
                Console.WriteLine(in_text);
            }

            if ((in_outMode & BIT_LOG_FILE) != 0)
            {
                StreamWriter logFile = null;
                logFile = new StreamWriter(m_nameLogFileFullPath, true, Encoding.GetEncoding("windows-1252"));
                logFile.WriteLine(in_text);
                logFile.Close();
            }

            if ((in_outMode & BIT_RESULT_FILE) != 0)
            {
                StreamWriter resultFile = null;
                resultFile = new StreamWriter(m_nameResultFileFullPath, true, Encoding.GetEncoding("windows-1252"));
                resultFile.WriteLine(in_text);
                resultFile.Close();
            }

        }

        
        //-----------------------------------------------------------
        // Private methods
        //-----------------------------------------------------------

        private void CreateLogFiles()
        {
            // Get name of application and executable path
            System.IO.FileInfo fi = new System.IO.FileInfo(System.Reflection.Assembly.GetEntryAssembly().Location);
            string appDirName = fi.DirectoryName;
            string appName = fi.Name;

            // Reset logfile
            string nameLogFile = appName.Replace(".exe", ".Log.txt");
            m_nameLogFileFullPath = Path.Combine(appDirName, nameLogFile);
            StreamWriter logFile = null;
            logFile = new StreamWriter(m_nameLogFileFullPath, false, Encoding.GetEncoding("windows-1252"));
            logFile.Close();

            // Reset result file
            string nameResultFile = appName.Replace(".exe", ".Results.txt");
            m_nameResultFileFullPath = Path.Combine(appDirName, nameResultFile);
            StreamWriter resultFile = null;
            resultFile = new StreamWriter(m_nameResultFileFullPath, false, Encoding.GetEncoding("windows-1252"));
            resultFile.Close();
        }
    }
}
